<!-- Forum thumbnail - shows icon placeholder -->
<div class="extractor-thumbnail forumdl-thumbnail" style="width: 100%; height: 100px; overflow: hidden; background: #1a1a1a; display: flex; align-items: center; justify-content: center;">
    <div style="display: flex; flex-direction: column; align-items: center; color: #888; font-size: 12px;">
        <span style="font-size: 32px;">💬</span>
        <span>Forum</span>
    </div>
</div>
