<!-- PDF thumbnail - shows first page preview -->
<div class="extractor-thumbnail pdf-thumbnail" style="width: 100%; height: 100px; overflow: hidden; background: #f5f5f5;">
    <embed src="{{ output_path }}#toolbar=0&navpanes=0&scrollbar=0&page=1&view=FitH"
           type="application/pdf"
           style="width: 100%; height: 200px; margin-top: -20px; pointer-events: none;">
</div>
