<span class="abx-output-icon abx-output-icon--media" title="Media"><svg width="16" height="16" viewBox="0 0 24 24" aria-hidden="true" focusable="false" fill="none" stroke="currentColor" stroke-width="1.8" stroke-linecap="round" stroke-linejoin="round"><rect x="3" y="5" width="18" height="14" rx="2"/><path d="M10 10l5 2-5 2.8z"/><path d="M17 9v5"/><path d="M17 14a1.5 1.5 0 1 0 1.5 1.5"/></svg></span>
