<!-- YT-DLP output list -->
{% if media_files %}
    <div class="loose-items" style="pointer-events: auto;">
        {% for file in media_files %}
            <a href="{{ file.url|default:file.path|urlencode }}" target="preview"
               title="{{ file.name }}">
                📄 {{ file.name }}
            </a>
        {% endfor %}
    </div>
{% else %}
    <div class="thumbnail-compact" data-plugin="ytdlp" data-compact="1">
        <span class="thumbnail-compact-icon">🎬</span>
        <span class="thumbnail-compact-label">YT-DLP</span>
        <span class="thumbnail-compact-meta">media</span>
    </div>
{% endif %}
