<span class="abx-output-icon abx-output-icon--defuddle" title="Defuddle"><svg width="16" height="16" viewBox="0 0 24 24" aria-hidden="true" focusable="false" fill="none" stroke="currentColor" stroke-width="1.8" stroke-linecap="round" stroke-linejoin="round"><rect x="3" y="5" width="18" height="14" rx="2"/><path d="M7 9h6"/><path d="M7 13h7"/><path d="M17 7.5v5"/><path d="M14.5 10h5"/><path d="M15.2 8.2l3.6 3.6"/><path d="M18.8 8.2l-3.6 3.6"/></svg></span>
