<!-- YT-DLP fullscreen - full video/audio player -->
<div class="extractor-fullscreen ytdlp-fullscreen" style="width: 100%; height: 100vh; background: #000; display: flex; align-items: center; justify-content: center;">
    <video src="{{ output_path }}"
           style="max-width: 100%; max-height: 100%;"
           controls
           autoplay
           preload="auto">
        Your browser does not support the video tag.
    </video>
</div>
